<?php

class FileUpload {

	/**
	 *	@var	(arr) aAllowedFileTypes	This array stores all the information about the filetypes which should be allowed for the uploaded files
	 *	@var	(arr) aErrorReport		This array stores the error information for any errors which might have occured
	 *	@var	(arr) aUploaded			This array stores information about the files which have been uploaded succesfully
	 *	@var	(obj) oFileObject		This is an object referencing to an object ($_FILES)
	 *	@var	(boo) bMultiple			This boolean is set to true when multiple file uploads are allowed, default is false
	 *	@var	(int) iMaxSize			The maximum size of the uploaded files in bytes (0=unlimited)
	 *	@var	(str) sNewName			The new name of the individual file
	 *****/

	var $aAllowedFileTypes = array();
	var $aErrorReport = array();
	var $aUploaded = array();
	var $oFileObject;
	var $bMultiple = false;
	var $iMaxSize = 0;
	var $sNewName = '';
	
	/**
	 *	@name		FileUpload [contructor]
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@param	(obj) aFileObject		A reference to the $_FILES array
	 *****/
	
	function FileUpload(&$aFileObject) {
	
		$this->oFileObject = $aFileObject;
	
	}
	
	/**
     *	@name		addError
     *	@date		08/04/2006 (dd/mm/yyyy)
     *	@author		Gerard Klomp <gerard@theprodukt.com>
     *
     *	@param	(str) sFileName			The name of the uploaded file
     *	@param	(str) iErrorCode		The error code of the $_FILES['error']
     *
     *	@return	(boo)					Always returns the boolean true
     *****/
	
	function addError($sFileName, $iFileSize, $iErrorCode) {
	
		$iErrors = count($this->aErrorReport);
					
		$this->aErrorReport[$iErrors]['name'] 	= $sFileName;
		$this->aErrorReport[$iErrors]['error'] 	= $iErrorCode;
		$this->aErrorReport[$iErrors]['size']	= $iFileSize;
		
		switch($iErrorCode) {
			case 0:
				$this->aErrorReport[$iErrors]['description'] = 'There is no error, the file uploaded with success';
				break;
				
			case 1:
				$this->aErrorReport[$iErrors]['description'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini';
				break;
				
			case 2:
				$this->aErrorReport[$iErrors]['description'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
				break;
				
			case 3:
				$this->aErrorReport[$iErrors]['description'] = 'The uploaded file was only partially uploaded';
				break;
				
			case 4:
				$this->aErrorReport[$iErrors]['description'] = 'No file was uploaded';
				break;
				
			case 6:
				$this->aErrorReport[$iErrors]['description'] = 'Missing a temporary folder';
				break;
				
			case 11:
				$this->aErrorReport[$iErrors]['description'] = 'The extension of the file is not allowed';
				break;
				
			case 12:
				$this->aErrorReport[$iErrors]['description'] = 'The MIME-Type of the file is not allowed';
				break;
				
			case 13:
				$this->aErrorReport[$iErrors]['description'] = 'The uploaded file is too large';
				break;
				
			case 14:
				$this->aErrorReport[$iErrors]['description'] = 'The file could not be moved';
				break; 	
				
			default:
				$this->aErrorReport[$iErrors]['description'] = 'An unknown error occured';
				
		}
		
	} // End of function (addError)
	
	function addUploaded($sFileName, $iSize) {
	
		$iUploaded = count($this->aUploaded);
		
		$this->aUploaded[$iUploaded]['name'] = $sFileName;
		$this->aUploaded[$iUploaded]['size'] = $iSize;
	
	}
	
	/**
	 *	@name		addFileType
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@param	(str) sExtension		The extension which should be allowed
	 *	@param	(str) sMimeType			The MIME-Type belonging to this extension
	 *
	 *	@return (boo) 					Always returns the boolean true
	 *****/
	
	function addFileType($sExtension, $sMimeType) {
		
		$this->aAllowedFileTypes[$sExtension] = $sMimeType;
		return true;
		
	}
	
	/**
	 *	@name		enableMultiple
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@param	(boo) bEnableMultiple	Enables/Disables the function to upload multiple files
	 *
	 *	@return	(boo)					Always returns the boolean true
	 *****/
	
	function enableMultiple($bEnableMultiple) {
	
		$this->bMultiple = (is_bool($bEnableMultiple) && $bEnableMultiple === true ? true : false);
		return true;
		
	}
	
	/**
	 *	@name		setMaxSize
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@param	(int) iMaxSize			The maximum size in bytes the uploaded files must comply to
	 *
	 *	@return (boo)					Always returns the boolean true
	 *****/
	
	function setMaxSize($iMaxSize = 0) {
	
		$this->iMaxSize = (is_numeric($iMaxSize) && $iMaxSize >= 0 ? $iMaxSize : $this->iMaxSize);
		return true;
	
	}
	
	/**
	 *	@name		setNewName
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@param	(str) sNewName			The new name of the individual file
	 *
	 *	@return (boo)					Always returns the boolean true
	 *****/
	
	function setNewName($sNewName) {
	
		$this->sNewName = $sNewName;
		return true;
	
	}
	
	/**
	 *	@name		getErrors
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@return	(mix)					Returns an array of errors if they have occured, else it returns false
	 *****/
	
	function getErrors() {
	
		return (count($this->aErrorReport) > 0 ? $this->aErrorReport : false);
		
	}
	
	/**
	 *	@name		getUploaded
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@return	(arr)					Returns an array with information about all the succesfull uploads
	 *****/
	
	function getUploaded() {
	
		return $this->aUploaded;
		
	}
	
	/**
	 *	@name		moveFiles
	 *	@date		08/04/2006 (dd/mm/yyyy)
	 *	@author		Gerard Klomp <gerard@theprodukt.com>
	 *
	 *	@param	(str) sDirectory		The directory to which all the files should be moved
	 *
	 *	@return (boo)					Returns a boolean true if all actions succeeded
	 *****/
	
	function moveFiles($sDirectory) {
	
		// Controleren of het laatste teken van de directorynaam een forwardslash is, zoja dan deze verwijderen
		$sDirectory = (substr($sDirectory, strlen($sDirectory) - 1, strlen($sDirectory)) == '/' ? substr($sDirectory, 0, strlen($sDirectory) - 1) : $sDirectory);
	
		if (is_array($this->oFileObject['name']) && $this->bMultiple == true) {
		
			$iArrayLength = count($this->oFileObject['name']);
			
			for ($i = 0; $i < $iArrayLength; $i++) {
			
				// Controleren of de extensie toegestaan is en het MIME-Type
				$sFileExtension = array_pop(explode('.', $this->oFileObject['name'][$i]));
				
				if (array_key_exists(strtolower($sFileExtension), $this->aAllowedFileTypes) && (is_array($this->aAllowedFileTypes[strtolower($sFileExtension)]) ? in_array($this->oFileObject['type'][$i], $this->aAllowedFileTypes[strtolower($sFileExtension)]) : $this->aAllowedFileTypes[strtolower($sFileExtension)] == $this->oFileObject['type'][$i]) && ($this->iMaxSize == 0 || $this->oFileObject['size'][$i] < $this->iMaxSize)) {
	
					$sFileName = $this->oFileObject['name'][$i];
					$iFileSize = $this->oFileObject['size'][$i];
					
					if (move_uploaded_file($this->oFileObject['tmp_name'][$i], $sDirectory.'/'.$this->oFileObject['name'][$i])) {
					
						$this->addUploaded($sFileName, $iFileSize);
					
					} else {
					
						$this->addError($sFileName, $iFileSize, 14);
						
					}
				
				} else {
				
					if(($this->oFileObject['type'][$i] <> '') && (!array_key_exists(strtolower($sFileExtension), $this->aAllowedFileTypes))) {
					
						$this->addError($this->oFileObject['name'][$i], $this->oFileObject['size'][$i], 11);
						
					} elseif (($this->oFileObject['type'][$i] <> '') && (is_array($this->aAllowedFileTypes[strtolower($sFileExtension)]) ? !in_array($this->oFileObject['type'][$i], $this->aAllowedFileTypes[strtolower($sFileExtension)]) : $this->aAllowedFileTypes[strtolower($sFileExtension)] <> $this->oFileObject['type'][$i])) {
					
						$this->addError($this->oFileObject['name'][$i], $this->oFileObject['size'][$i], 12);
						
					} elseif($this->iMaxSize <> 0 && $this->oFileObject['size'][$i] > $this->iMaxSize) {
					
						$this->addError($this->oFileObject['name'][$i], $this->oFileObject['size'][$i], 13);
					
					} else {
					
						$this->addError($this->oFileObject['name'][$i], $this->oFileObject['size'][$i], $this->oFileObject['error'][$i]);
						
					}
				
				}			
			
			}
		
		} elseif (!is_array($this->oFileObject['name'])) {
		
				// Controleren of de extensie toegestaan is en het MIME-Type
				$sFileExtension = array_pop(explode('.', $this->oFileObject['name']));

				if (array_key_exists(strtolower($sFileExtension), $this->aAllowedFileTypes) && (is_array($this->aAllowedFileTypes[strtolower($sFileExtension)]) ? in_array($this->oFileObject['type'], $this->aAllowedFileTypes[strtolower($sFileExtension)]) : $this->aAllowedFileTypes[strtolower($sFileExtension)] == $this->oFileObject['type']) && ($this->iMaxSize == 0 || $this->oFileObject['size'] < $this->iMaxSize)) {
	
					$sFileName = ($this->sNewName == '' ? $this->oFileObject['name'] : $this->sNewName.'.'.$sFileExtension);
					$iFileSize = $this->oFileObject['size'];
					
					if (move_uploaded_file($this->oFileObject['tmp_name'], $sDirectory.'/'.$sFileName)) {
					
						$this->addUploaded($sFileName, $iFileSize);
					
					} else {
					
						$this->addError($sFileName, $iFileSize, 14);
						
					}
				
				} else {
				
					if(($this->oFileObject['type'] <> '') && (!array_key_exists(strtolower($sFileExtension), $this->aAllowedFileTypes))) {
					
						$this->addError($this->oFileObject['name'], $this->oFileObject['size'], 11);
						
					} elseif (($this->oFileObject['type'] <> '') && (is_array($this->aAllowedFileTypes[strtolower($sFileExtension)]) ? !in_array($this->oFileObject['type'], $this->aAllowedFileTypes[strtolower($sFileExtension)]) : $this->aAllowedFileTypes[strtolower($sFileExtension)] <> $this->oFileObject['type'])) {
					
						$this->addError($this->oFileObject['name'], $this->oFileObject['size'], 12);
						
					} elseif($this->iMaxSize <> 0 && $this->oFileObject['size'] > $this->iMaxSize) {
					
						$this->addError($this->oFileObject['name'], $this->oFileObject['size'], 13);
					
					} else {
					
						$this->addError($this->oFileObject['name'], $this->oFileObject['size'], $this->oFileObject['error']);
						
					}
				
				}
		
		}
	
	} // End of function (moveFiles)

}

?>